Name:	 frobby
Summary: Computations With Monomial Ideals
Version: 0.9.0
Release: 9%{?dist}

License: GPLv2+
URL:	 http://www.broune.com/frobby/
Source0: http://www.broune.com/frobby/frobby_v%{version}.tar.gz

# make makefile a wee bit more sane
Patch1: frobby-0.9.0-makefile.patch
# https://raw.githubusercontent.com/Macaulay2/M2/master/M2/libraries/frobby/patch-0.9.0
Patch2: frobby-0.9.0-Macaulay2.patch

BuildRequires: gmp-devel
# docs
BuildRequires: doxygen-latex

Requires: lib%{name}%{?_isa} = %{version}-%{release}

%description
Frobby is a software system and project for computations with monomial
ideals. Frobby is free software and it is intended as a vehicle for
research on monomial ideals, as well as a useful practical tool for
investigating monomial ideals.

The current functionality includes Hilbert series, maximal standard
monomials, combinatorial optimization on monomial ideals, primary
decomposition, irreducible decomposition, Alexander dual, associated
primes, minimization and intersection of monomial ideals as well as
the computation of Frobenius problems (using 4ti2) with very large
numbers. Frobby is also able to translate between formats that can be used
with several different computer systems, such as Macaulay 2, Monos, 4ti2,
CoCoA4 and Singular. Thus Frobby can be used with any of those systems.


%package -n libfrobby
Summary:        Frobby internals as a library

%description -n libfrobby
This package contains the frobby internals as a library, often called
libfrobby.


%package -n libfrobby-devel
Summary:        Developer files for libfrobby
Requires:       lib%{name}%{?_isa} = %{version}-%{release}
Requires:       gmp-devel%{?_isa}

%description -n libfrobby-devel
Header files and library links to develop applications that use the
Frobby internals as a library (libfrobby).


%prep
%setup -q -n frobby_v%{version}

%patch1 -p1 -b .makefile
%patch2 -p1 -b .Macaulay2

# Remove all file executable bits and restore the few appropriate cases
find . -type f -perm /0111 -exec chmod a-x {} +
chmod a+x frobgrob test/run* test/*/make* test/*/run* test/bench/benchHelper \
  test/testScripts/testhelper


%build
make %{?_smp_mflags} \
  BIN_INSTALL_DIR=%{_bindir} \
  CFLAGS="${CFLAGS:-%optflags}" \
  GMP_INC_DIR=%{_includedir} \
  LDFLAGS="${LDFLAGS:-%__global_ldflags}" \
  MODE=shared \
  library all

# Relink the binary against the library
rm bin/frobby
mv bin/libfrobby.so bin/libfrobby.so.0.0.0
ln -s libfrobby.so.0.0.0 bin/libfrobby.so.0
ln -s libfrobby.so.0 bin/libfrobby.so
g++ bin/shared/main.o ${CFLAGS:-%optflags} ${LDFLAGS:-%__global_ldflags} \
  -L$PWD/bin -lfrobby -o bin/frobby

# generate docs
make docPdf


%install
# Install the binary
mkdir -p %{buildroot}/%{_bindir}
cp -p bin/frobby %{buildroot}%{_bindir}

# Install the library
mkdir -p %{buildroot}%{_libdir}
cp -p bin/libfrobby.so.0.0.0 %{buildroot}%{_libdir}
ln -s libfrobby.so.0.0.0 %{buildroot}%{_libdir}/libfrobby.so.0
ln -s libfrobby.so.0 %{buildroot}%{_libdir}/libfrobby.so

# Install the header file
mkdir -p %{buildroot}%{_includedir}
cp -p src/frobby.h %{buildroot}%{_includedir}


%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
test/runTests


%post -n libfrobby -p /sbin/ldconfig

%postun -n libfrobby -p /sbin/ldconfig


%files
%doc bin/manual.pdf
%{_bindir}/frobby

%files -n libfrobby
%doc COPYING
%{_libdir}/*.so.0*

%files -n libfrobby-devel
%{_includedir}/frobby.h
%{_libdir}/*.so


%changelog
* Fri Feb 24 2017 Jerry James <loganjerry@gmail.com> - 0.9.0-9
- Add libfrobby and libfrobby-devel subpackages

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.9.0-5
- Rebuilt for GCC 5 C++11 ABI change

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jul 07 2014 Rex Dieter <rdieter@fedoraproject.org> 0.9.0-3
- fix W: spurious-executable-perm /usr/share/doc/frobby/COPYING

* Mon Jun 23 2014 Rex Dieter <rdieter@fedoraproject.org> 0.9.0-2
- explicitly set CFLAGS, LDFLAGS

* Mon Jun 23 2014 Rex Dieter <rdieter@fedoraproject.org> 0.9.0-1
- frobby-0.9.0

* Thu May 26 2011 Rex Dieter <rdieter@fedoraproject.org> 0.8.2-1
- first try

